@@ -117,7 +117,7 @@ class Buffer(object):
         if self.mode == 'consume':
             return len(self.data)
         elif self.mode == 'index':
-            return len(self.data) - self.pos
+            return max(len(self.data) - self.pos, 0)
     
     def __get_slice__(self, start, end):
         return self.part(self, start, end)
