@@ -1,7 +1,7 @@
 from dez.http.client import HTTPClientRequest, HTTPClient
 import event
 
-def main():
+def main(port):
 #    event.initialize(["poll"])
     client = HTTPClient()
     client.get_connection("www.google.com", 80, get_conn_cb, [])
