@@ -1,8 +1,8 @@
 from dez.network import SocketClient, SocketDaemon, Connection
 import sys
 
-def main():
-    server = SocketDaemon("localhost", 9119, cb=TestCloseChunked)
+def main(port):
+    server = SocketDaemon("localhost", port, cb=TestCloseChunked)
     server.start()
 
 
@@ -52,5 +52,3 @@ class TestDelimiter(object):
 #    def close(self):
 #        self.conn.close()
 
-if __name__ == '__main__':
-    main()
